summaryrefslogtreecommitdiffstats
path: root/src/H5Fdeprec.c
diff options
context:
space:
mode:
authorM. Scot Breitenfeld <brtnfld@hdfgroup.org>2018-05-11 16:45:03 (GMT)
committerM. Scot Breitenfeld <brtnfld@hdfgroup.org>2018-05-11 16:45:03 (GMT)
commit6da75cffd2356fb5b5b92204b2d1c34a0e2e99ea (patch)
treef650fd5a94b0abe52de4c0b2c84fac52574f9ff3 /src/H5Fdeprec.c
parent88e0c3e748783b040bebdc014ca717e6b5ec2df6 (diff)
downloadhdf5-6da75cffd2356fb5b5b92204b2d1c34a0e2e99ea.zip
hdf5-6da75cffd2356fb5b5b92204b2d1c34a0e2e99ea.tar.gz
hdf5-6da75cffd2356fb5b5b92204b2d1c34a0e2e99ea.tar.bz2
Fixed libver bounds underscore issue
Diffstat (limited to 'src/H5Fdeprec.c')
-rw-r--r--src/H5Fdeprec.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/H5Fdeprec.c b/src/H5Fdeprec.c
index f220e77..703c9cc 100644
--- a/src/H5Fdeprec.c
+++ b/src/H5Fdeprec.c
@@ -149,7 +149,7 @@ done:
* Purpose: Enable switching between latest or non-latest format while
* a file is open.
* This is deprecated starting release 1.10.2 and is modified
* to call the private H5F_set_libver_bounds() to set the
* bounds.
*
* Before release 1.10.2, the library supports only two
@@ -198,7 +198,7 @@ H5Fset_latest_format(hid_t file_id, hbool_t latest_format)
low = H5F_LIBVER_EARLIEST;
/* Call private set_libver_bounds function to set the bounds */
- if(H5F_set_libver_bounds(f, low, high) < 0)
+ if(H5F__set_libver_bounds(f, low, high) < 0)
HGOTO_ERROR(H5E_FILE, H5E_CANTSET, FAIL, "cannot set low/high bounds")
done:
@@ -149,7 +149,7 @@ done:
* a file is open.
* This is deprecated starting release 1.10.2 and is modified
- * to call the private H5F_set_libver_bounds() to set the
+ * to call the private H5F__set_libver_bounds() to set the
* bounds.
*